# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import common
from . import test_survey
from . import test_survey_controller
from . import test_survey_flow
from . import test_survey_flow_with_conditions
from . import test_certification_flow
from . import test_survey_invite
from . import test_survey_security
from . import test_survey_randomize
from . import test_survey_ui_backend
from . import test_survey_ui_certification
from . import test_survey_ui_feedback
from . import test_survey_ui_session
from . import test_survey_compute_pages_questions
from . import test_certification_badge
from . import test_survey_performance
from . import test_survey_results
